@@ -1,7 +1,9 @@
-__version__ = "0.3.0"
+__version__ = "0.6.0"
 
 from .app import App as App
 from .fastapi import FastAPIDependency as FastAPIDependency
 from .fastapi import FastAPIErrorHandler as FastAPIErrorHandler
+from .module_options._actions import action as action
+from .module_options._metadata import Metadata as Metadata
 from .modules._error import ErrorHandlerMapping as ErrorHandlerMapping
-from .modules._metadata import Metadata as Metadata
+from .modules._layout import without_layout as without_layout
